# Generated by Django 2.1.4 on 2019-01-04 10:48

import core.models
from django.conf import settings
import django.contrib.postgres.fields.jsonb
import django.core.files.storage
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('auth', '0009_alter_user_last_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='Block',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=512)),
                ('workflow_state', models.PositiveSmallIntegerField(choices=[(0, 'Draft'), (1, 'Shared'), (2, 'Published'), (3, 'Archived')], default=0)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'ordering': ('-updated_at',),
            },
        ),
        migrations.CreateModel(
            name='DocumentMetadata',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.CharField(max_length=512)),
                ('document', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.Document')),
            ],
        ),
        migrations.CreateModel(
            name='DocumentPart',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False, verbose_name='order')),
                ('name', models.CharField(blank=True, max_length=512)),
                ('image', models.ImageField(upload_to=core.models.document_images_path)),
                ('bw_backend', models.CharField(default='kraken', max_length=128)),
                ('bw_image', models.ImageField(blank=True, null=True, upload_to=core.models.document_images_path)),
                ('workflow_state', models.PositiveSmallIntegerField(choices=[(0, 'Created'), (1, 'Compressing'), (2, 'Compressed'), (3, 'Binarizing'), (4, 'Binarized'), (5, 'Segmenting'), (6, 'Segmented'), (7, 'Transcribing')], default=0)),
                ('transcription_progress', models.PositiveSmallIntegerField(default=0)),
                ('document', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='parts', to='core.Document')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DocumentProcessSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('auto_process', models.BooleanField(default=True)),
                ('text_direction', models.CharField(choices=[('horizontal-lr', 'Horizontal'), ('vertical-lr', 'Vertical')], default='horizontal-lr', max_length=64)),
                ('binarizer', models.CharField(choices=[('kraken', 'Kraken')], default='kraken', max_length=64)),
                ('document', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='process_settings', to='core.Document')),
            ],
        ),
        migrations.CreateModel(
            name='Line',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False, verbose_name='order')),
                ('box', django.contrib.postgres.fields.jsonb.JSONField()),
                ('script', models.CharField(blank=True, max_length=8, null=True)),
                ('block', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Block')),
                ('document_part', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='lines', to='core.DocumentPart')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='LineTranscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('revision', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('version_source', models.CharField(default='escriptorium', editable=False, max_length=128)),
                ('version_author', models.CharField(editable=False, max_length=128)),
                ('version_created_at', models.DateTimeField(auto_now_add=True)),
                ('version_updated_at', models.DateTimeField(auto_now=True)),
                ('versions', django.contrib.postgres.fields.jsonb.JSONField(default=list, editable=False)),
                ('content', models.CharField(max_length=2048, null=True)),
                ('graphs', django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True)),
                ('line', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='transcriptions', to='core.Line')),
            ],
        ),
        migrations.CreateModel(
            name='Metadata',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128, unique=True)),
                ('cidoc_id', models.CharField(blank=True, max_length=8, null=True)),
            ],
            options={
                'ordering': ('name',),
            },
        ),
        migrations.CreateModel(
            name='OcrModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=256, unique=True)),
                ('file', models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/home/robin/.config/kraken'), upload_to='', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['clstm', 'pronn'])])),
                ('trained', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Transcription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=512)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('document', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcriptions', to='core.Document')),
            ],
        ),
        migrations.CreateModel(
            name='Typology',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128)),
                ('target', models.PositiveSmallIntegerField(choices=[(1, 'Document'), (2, 'Part (eg Page)'), (3, 'Block (eg Paragraph)')])),
            ],
        ),
        migrations.AddField(
            model_name='linetranscription',
            name='transcription',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.Transcription'),
        ),
        migrations.AddField(
            model_name='documentprocesssettings',
            name='ocrmodel',
            field=models.ForeignKey(blank=True, limit_choices_to={'trained': True}, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.OcrModel', verbose_name='Model'),
        ),
        migrations.AddField(
            model_name='documentprocesssettings',
            name='typology',
            field=models.ForeignKey(blank=True, limit_choices_to={'target': 2}, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Typology'),
        ),
        migrations.AddField(
            model_name='documentpart',
            name='typology',
            field=models.ForeignKey(blank=True, limit_choices_to={'target': 2}, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Typology'),
        ),
        migrations.AddField(
            model_name='documentmetadata',
            name='key',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.Metadata'),
        ),
        migrations.AddField(
            model_name='document',
            name='metadatas',
            field=models.ManyToManyField(blank=True, through='core.DocumentMetadata', to='core.Metadata'),
        ),
        migrations.AddField(
            model_name='document',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='document',
            name='shared_with_groups',
            field=models.ManyToManyField(blank=True, related_name='shared_documents', to='auth.Group', verbose_name='Share with teams'),
        ),
        migrations.AddField(
            model_name='document',
            name='shared_with_users',
            field=models.ManyToManyField(blank=True, related_name='shared_documents', to=settings.AUTH_USER_MODEL, verbose_name='Share with users'),
        ),
        migrations.AddField(
            model_name='document',
            name='typology',
            field=models.ForeignKey(blank=True, limit_choices_to={'target': 1}, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Typology'),
        ),
        migrations.AddField(
            model_name='block',
            name='document_part',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.DocumentPart'),
        ),
        migrations.AddField(
            model_name='block',
            name='typology',
            field=models.ForeignKey(limit_choices_to={'target': 3}, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Typology'),
        ),
        migrations.AlterUniqueTogether(
            name='transcription',
            unique_together={('name', 'document')},
        ),
        migrations.AlterUniqueTogether(
            name='linetranscription',
            unique_together={('line', 'transcription')},
        ),
    ]
